==> wmh_segement-0.0.1.tar.gz: lib/wmh_segement.dart <==
import 'package:flutter/material.dart';

class WMHSegement extends StatefulWidget {
  final List<Map> paramPages;
  final Color itemColor;//显示标题的颜色
  final Color indicateColor;//下划线颜色
  final double itemTitleFont;//显示标题大小
  final Color selectedColor;//当前项颜色
  final Color unSelectColor;//未选中项颜色
  final double indicatorHeight;//选中条高度
  final bool haveSeperateLine;//是否有分割线
  final List<Widget> bottomViewArr;//子视图
  bool titleCanScroll = true;//标题栏能否滑动
  final Widget titleWidget;

  WMHSegement({
    @required this.paramPages,
    @required this.itemColor,
    @required this.indicateColor,
    @required this.itemTitleFont,
    @required this.selectedColor,
    @required this.unSelectColor,
    @required this.indicatorHeight,
    @required this.haveSeperateLine,
    @required this.bottomViewArr,
    @required this.titleWidget,
  });

  WMHSegementState createState() => WMHSegementState();
}

class WMHSegementState extends State<WMHSegement> with SingleTickerProviderStateMixin {
  TabController _controller;
  int currentIndex = 0;

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    _controller = new TabController(length: widget.paramPages.length, vsync: this);
  }

  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();
    _controller.dispose();
  }

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Scaffold(
      appBar: AppBar(
        elevation: 0,
        backgroundColor: Colors.white,
        title: widget.titleWidget,
        bottom: new TabBar(
          controller: _controller,
          isScrollable: widget.titleCanScroll,
          indicatorWeight: widget.indicatorHeight,
          indicatorColor: widget.indicateColor,
          labelColor: widget.unSelectColor,
          tabs: widget.paramPages.map((Map myDic) {
            return new Tab(child: GestureDetector(
              child: Container(
                child: Text(
                  myDic['text'].toString(),
                  style: TextStyle(
                    color: widget.itemColor,
                    fontSize: widget.itemTitleFont,
                  ),
                ),
              ),
            ));
          }).toList(),
        ),
      ),
      body: Container(
        child: Column(
          children: <Widget>[
            widget.haveSeperateLine == true ? Container(
              child: Divider(height: 0.5),
            ) : Container(width: 0.0, height: 0.0),
            Expanded(
              child: new TabBarView(
                controller: _controller,
                children: widget.bottomViewArr,
              ),
            ),
          ],
        ),
      ),
    );
  }
}

==> wmh_segement-0.0.2.tar.gz: lib/wmh_segement.dart <==
import 'package:flutter/material.dart';

class WMHSegement extends StatefulWidget {
  final Color appbarColor;//导航栏颜色
  final Widget leadingWidget;//左控件
  final List<Map> paramPages;
  final Color itemColor;//显示标题的颜色
  final Color indicateColor;//下划线颜色
  final double itemTitleFont;//显示标题大小
  final Color selectedColor;//当前项颜色
  final Color unSelectColor;//未选中项颜色
  final double indicatorHeight;//选中条高度
  final bool haveSeperateLine;//是否有分割线
  final List<Widget> bottomViewArr;//子视图
  bool titleCanScroll = true;//标题栏能否滑动
  final Widget titleWidget;

  WMHSegement({
    @required this.appbarColor,
    @required this.leadingWidget,
    @required this.paramPages,
    @required this.itemColor,
    @required this.indicateColor,
    @required this.itemTitleFont,
    @required this.selectedColor,
    @required this.unSelectColor,
    @required this.indicatorHeight,
    @required this.haveSeperateLine,
    @required this.bottomViewArr,
    @required this.titleWidget,
  });

  WMHSegementState createState() => WMHSegementState();
}

class WMHSegementState extends State<WMHSegement> with SingleTickerProviderStateMixin {
  TabController _controller;
  int currentIndex = 0;

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    _controller = new TabController(length: widget.paramPages.length, vsync: this);
  }

  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();
    _controller.dispose();
  }

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Scaffold(
      appBar: AppBar(
        elevation: 0,
        backgroundColor: widget.appbarColor,
        title: widget.titleWidget,
        leading: widget.leadingWidget,
        bottom: new TabBar(
          controller: _controller,
          isScrollable: widget.titleCanScroll,
          indicatorWeight: widget.indicatorHeight,
          indicatorColor: widget.indicateColor,
          labelColor: widget.unSelectColor,
          tabs: widget.paramPages.map((Map myDic) {
            return new Tab(child: GestureDetector(
              child: Container(
                child: Text(
                  myDic['text'].toString(),
                  style: TextStyle(
                    color: widget.itemColor,
                    fontSize: widget.itemTitleFont,
                  ),
                ),
              ),
            ));
          }).toList(),
        ),
      ),
      body: Container(
        child: Column(
          children: <Widget>[
            widget.haveSeperateLine == true ? Container(
              child: Divider(height: 0.5),
            ) : Container(width: 0.0, height: 0.0),
            Expanded(
              child: new TabBarView(
                controller: _controller,
                children: widget.bottomViewArr,
              ),
            ),
          ],
        ),
      ),
    );
  }
}
